Struct plaid::item::GetItemResponse[][src]

pub struct GetItemResponse {
    pub request_id: String,
    pub item: Item,
    pub status: Option<ItemStatus>,
    pub access_token: Option<String>,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

item: Item

Metadata about the Item.

status: Option<ItemStatus>

An object with information about the status of the Item.

access_token: Option<String>

The access token associated with the Item data is being requested for.