Struct plaid::item::Item[][src]

pub struct Item {
    pub item_id: String,
    pub institution_id: Option<String>,
    pub webhook: Option<String>,
    pub error: Option<ErrorResponse>,
    pub available_products: Vec<String>,
    pub billed_products: Vec<String>,
    pub consent_expiration_time: Option<DateTime<Utc>>,
    pub update_type: String,
}

Metadata about the Item.

Fields

item_id: String

The Plaid Item ID.

institution_id: Option<String>

The Plaid Institution ID associated with the Item. Field is null for Items created via Same Day Micro-deposits.

webhook: Option<String>

The URL registered to receive webhooks for the Item.

error: Option<ErrorResponse>

We use standard HTTP response codes for success and failure notifications, and our errors are further classified by error_type.

available_products: Vec<String>

A list of products available for the Item that have not yet been accessed.

billed_products: Vec<String>

A list of products that have been billed for the Item. Note - billed_products is populated in all environments but only requests in Production are billed.

consent_expiration_time: Option<DateTime<Utc>>

The RFC 3339 timestamp after which the consent provided by the end user will expire.

update_type: String

Indicates whether an Item requires user interaction to be updated, which can be the case for Items with some forms of two-factor authentication.