Struct plaid::item::ProductStatus [−][src]
Fields
last_successful_update: Option<DateTime<Utc>>ISO 8601 timestamp of the last successful transactions update for the Item. The status will update each time Plaid successfully connects with the institution, regardless of whether any new data is available in the update.
last_failed_update: Option<DateTime<Utc>>ISO 8601 timestamp of the last failed transactions update for the Item. The status will update each time Plaid fails an attempt to connect with the institution, regardless of whether any new data is available in the update.